@@ -114,7 +114,7 @@ class ListingResource:
     
     def get_listings_by_listing_ids(self, listing_ids: List[int], includes: str = ""):
         params = {
-            "listing_ids":",".join(listing_ids),
+            "listing_ids":",".join(list(map(str, listing_ids))),
             "includes":includes
         }
         endpoint = "https://openapi.etsy.com/v3/application/listings/batch"
